# Strange issue with similarity scores on ES 0.90.0 - possibly shard related?

**URL:** <https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057>\
**Category:** Elasticsearch\
**Created:** [May 21, 2013, 4:33pm UTC](https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057 "2013-05-21T16:33:10Z")\
**Posts on this page:** 7\
**Page:** 1

<div class="post-metadata">

**Author:** ![Derry\_O\_Sullivan](https://avatars.discourse-cdn.com/v4/letter/d/7bcc69/32.png) [@Derry\_O\_Sullivan](https://discuss.elastic.co/u/Derry_O_Sullivan)\
**Post date:** [May 21, 2013, 4:33pm UTC](https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057/1 "2013-05-21T16:33:10Z")

</div>

Hi all,

We've noticed a strange issue with similarity scores on ES. The outline of  
the bug is that we get different tfidf scores back for exactly the same  
documents (e.g. duplicate documents) after a number of document inserts.

Steps to reproduce:

1. Start a clean ES setup
2. No index/type mapping should be created
3. Add some content:  
curl -XPUT '[http://localhost:9200/items/item/1](http://localhost:9200/items/item/1)' -d  
'{"language":"en","description":"some crm description data","title":"some  
crm title data"}'

So 1 document in a new index called items with a type called item:

1. Search for that 1 doc and check the score:  
[http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)  
0.13561106

2. Start adding that same doc multiple times (search every few occurences)  
curl -XPUT '[http://localhost:9200/items/item/2](http://localhost:9200/items/item/2)' -d  
'{"language":"en","description":"some crm description data","title":"some  
crm title data"}'  
curl -XPUT '[http://localhost:9200/items/item/3](http://localhost:9200/items/item/3)' -d  
'{"language":"en","description":"some crm description data","title":"some  
crm title data"}'  
curl -XPUT '[http://localhost:9200/items/item/4](http://localhost:9200/items/item/4)' -d  
'{"language":"en","description":"some crm description data","title":"some  
crm title data"}'  
curl -XPUT '[http://localhost:9200/items/item/5](http://localhost:9200/items/item/5)' -d  
'{"language":"en","description":"some crm description data","title":"some  
crm title data"}'

3. Search again:  
[http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)  
Should get the same score as above for all the docs:

4. Search with title field:  
[http://localhost:9200/items/item/\_search?q=title:crm](http://localhost:9200/items/item/_search?q=title:crm)  
Same score for all docs (slightly higher but because we check on only 1  
field vs all)  
0.15342641

_Gets interesting here!_  
\*

- 
  1. Add some new docs with slightly different text:  
curl -XPUT '[http://localhost:9200/items/item/6](http://localhost:9200/items/item/6)' -d  
'{"language":"en","description":"some crm description data","title":"some  
crm title data _crm_"}'  
curl -XPUT '[http://localhost:9200/items/item/7](http://localhost:9200/items/item/7)' -d  
'{"language":"en","description":"_some crm description crm_","title":"_crm  
crm_"}'

1. Now search again:  
[http://localhost:9200/items/item/\_search?q=title:crm](http://localhost:9200/items/item/_search?q=title:crm)

Notice that not all the docs get the same score. Obviously i would have  
expected different scores for document 6/7 - _but not all of documents 1-5  
(that are all the same) get the same score_:

- {
  - \_index: "items",
  - \_type: "item",
  - \_id: "2",
  - \_score: 0.2972674,
  - \_source:  
{
    - language: "en",
    - description: "some crm description data",
    - title: "some crm title data"  
}  
},

- 

{  
- \_index: "items",  
- \_type: "item",  
- \_id: "4",  
- \_score: 0.15342641,  
- \_source:  
{  
- language: "en",  
- description: "some crm description data",  
- title: "some crm title data"  
}  
}

1. Same if we don't search title explicitly:  
[http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)

Note the scores are completely different for the same  
title/description/etc. Is this issue related to sharding (e.g. documents  
mapping to a particular shard?) or something else? The same issue is seen  
if we add 6 documents (all the same) to an index with 5 shards - using the  
explain plan seems to show that maxDocs for tfidf is calculated over  
#shards. Is this expected?

We are using a completely blank es setup of ES 0.90.0, no complex  
analyzer/settings/mapping.

[http://localhost:9200/items/\_settings](http://localhost:9200/items/_settings)

{

- items:  
{
  - settings:  
{
    - index.number\_of\_shards: "5",
    - index.number\_of\_replicas: "1",
    - index.version.created: "900099"  
}  
}

}

[http://localhost:9200/\_mapping](http://localhost:9200/_mapping)  
{

- items:  
{
  - item:  
{
    - properties:  
{
      - description:  
{
        - type: "string"  
},

      - language:  
{
        - type: "string"  
},

      - title:  
{
        - type: "string"  
}  
}  
}  
}

}

Help as always greatly appreciated

Derry

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Randall\_McRee](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/randall_mcree/32/47177_2.png) [@Randall\_McRee](https://discuss.elastic.co/u/Randall_McRee)\
**Post date:** [May 21, 2013, 9:04pm UTC](https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057/2 "2013-05-21T21:04:27Z")

</div>

Its not strange, its expected....try DFS\_QUERY\_THEN\_FETCH search type:

> **[Elasticsearch Platform — Find real-time answers at scale](https://www.elastic.co)**
>
> Power insights and outcomes with the Elasticsearch Platform and AI. See into your data and find answers that matter with enterprise solutions designed to help you build, observe, and protect. Try Elasticsearch free today.

to solve this problem. Also omit\_norms if you dont want/need tfidf in a  
field.

On Tue, May 21, 2013 at 9:33 AM, Derry O' Sullivan [derryos@gmail.com](mailto:derryos@gmail.com)wrote:

> Hi all,
> 
> We've noticed a strange issue with similarity scores on ES. The outline of  
> the bug is that we get different tfidf scores back for exactly the same  
> documents (e.g. duplicate documents) after a number of document inserts.
> 
> Steps to reproduce:
> 
> 1. Start a clean ES setup
> 2. No index/type mapping should be created
> 3. Add some content:  
> curl -XPUT '[http://localhost:9200/items/item/1](http://localhost:9200/items/item/1)' -d  
> '{"language":"en","description":"some crm description data","title":"some  
> crm title data"}'
> 
> So 1 document in a new index called items with a type called item:
> 
> 1. Search for that 1 doc and check the score:  
> [http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)  
> 0.13561106
> 
> 2. Start adding that same doc multiple times (search every few occurences)  
> curl -XPUT '[http://localhost:9200/items/item/2](http://localhost:9200/items/item/2)' -d  
> '{"language":"en","description":"some crm description data","title":"some  
> crm title data"}'  
> curl -XPUT '[http://localhost:9200/items/item/3](http://localhost:9200/items/item/3)' -d  
> '{"language":"en","description":"some crm description data","title":"some  
> crm title data"}'  
> curl -XPUT '[http://localhost:9200/items/item/4](http://localhost:9200/items/item/4)' -d  
> '{"language":"en","description":"some crm description data","title":"some  
> crm title data"}'  
> curl -XPUT '[http://localhost:9200/items/item/5](http://localhost:9200/items/item/5)' -d  
> '{"language":"en","description":"some crm description data","title":"some  
> crm title data"}'
> 
> 3. Search again:  
> [http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)  
> Should get the same score as above for all the docs:
> 
> 4. Search with title field:  
> [http://localhost:9200/items/item/\_search?q=title:crm](http://localhost:9200/items/item/_search?q=title:crm)  
> Same score for all docs (slightly higher but because we check on only 1  
> field vs all)  
> 0.15342641
> 
> _Gets interesting here!_  
> \*
> 
> - 
> 1. Add some new docs with slightly different text:  
> curl -XPUT '[http://localhost:9200/items/item/6](http://localhost:9200/items/item/6)' -d  
> '{"language":"en","description":"some crm description data","title":"some  
> crm title data _crm_"}'  
> curl -XPUT '[http://localhost:9200/items/item/7](http://localhost:9200/items/item/7)' -d  
> '{"language":"en","description":"_some crm description crm_","title":"_crm  
> crm_"}'
> 
> 1. Now search again:  
> [http://localhost:9200/items/item/\_search?q=title:crm](http://localhost:9200/items/item/_search?q=title:crm)
> 
> Notice that not all the docs get the same score. Obviously i would have  
> expected different scores for document 6/7 - _but not all of documents  
> 1-5 (that are all the same) get the same score_:
> 
> - {
> - \_index: "items",
> - \_type: "item",
> - \_id: "2",
> - \_score: 0.2972674,
> - \_source:  
> {
> - language: "en",
> - description: "some crm description data",
> - title: "some crm title data"  
> }  
> },
> 
> - 
> 
> {  
> - \_index: "items",  
> - \_type: "item",  
> - \_id: "4",  
> - \_score: 0.15342641,  
> - \_source:  
> {  
> - language: "en",  
> - description: "some crm description data",  
> - title: "some crm title data"  
> }  
> }
> 
> 1. Same if we don't search title explicitly:  
> [http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)
> 
> Note the scores are completely different for the same  
> title/description/etc. Is this issue related to sharding (e.g. documents  
> mapping to a particular shard?) or something else? The same issue is seen  
> if we add 6 documents (all the same) to an index with 5 shards - using the  
> explain plan seems to show that maxDocs for tfidf is calculated over  
> #shards. Is this expected?
> 
> We are using a completely blank es setup of ES 0.90.0, no complex  
> analyzer/settings/mapping.
> 
> [http://localhost:9200/items/\_settings](http://localhost:9200/items/_settings)
> 
> {
> 
> - items:  
> {
> - settings:  
> {
> - index.number\_of\_shards: "5",
> - index.number\_of\_replicas: "1",
> - index.version.created: "900099"  
> }  
> }
> 
> }
> 
> [http://localhost:9200/\_mapping](http://localhost:9200/_mapping)  
> {
> 
> - items:  
> {
> - item:  
> {
> - properties:  
> {
> - description:  
> {
> - type: "string"  
> },
> 
> - language:  
> {
> - type: "string"  
> },
> 
> - title:  
> {
> - type: "string"  
> }  
> }  
> }  
> }
> 
> }
> 
> Help as always greatly appreciated
> 
> Derry
> 
> --  
> You received this message because you are subscribed to the Google Groups  
> "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an  
> email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Derry\_O\_Sullivan](https://avatars.discourse-cdn.com/v4/letter/d/7bcc69/32.png) [@Derry\_O\_Sullivan](https://discuss.elastic.co/u/Derry_O_Sullivan)\
**Post date:** [May 21, 2013, 11:08pm UTC](https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057/3 "2013-05-21T23:08:26Z")

</div>

Hi Randall,

Thanks for the response. I guess the real question is now why the ES  
default is 5 shards for new indexes (i understand about sharding from an  
indexing speed vs search speed perspective). If i redo the below with 1  
shard, i won't get this issue so in a 'small' index, it would make sense to  
have a smaller shard size.

I guess i would have expected this to be a bit more obvious in the  
documentation (e.g. watch out for unusual score values among un-even (if  
that is the term) shards? Is the assumption that documents can be (without  
routing) randomly spread among shards so the issue is not seen in a large  
dataset?

Derry  
On 21 May 2013 22:04, "Randall McRee" [randall.mcree@gmail.com](mailto:randall.mcree@gmail.com) wrote:

> Its not strange, its expected....try DFS\_QUERY\_THEN\_FETCH search type:  
> [Elasticsearch Platform — Find real-time answers at scale | Elastic](http://www.elasticsearch.org/guide/reference/api/search/search-type/)
> 
> to solve this problem. Also omit\_norms if you dont want/need tfidf in a  
> field.
> 
> On Tue, May 21, 2013 at 9:33 AM, Derry O' Sullivan [derryos@gmail.com](mailto:derryos@gmail.com)wrote:
> 
> > Hi all,
> > 
> > We've noticed a strange issue with similarity scores on ES. The outline  
> > of the bug is that we get different tfidf scores back for exactly the same  
> > documents (e.g. duplicate documents) after a number of document inserts.
> > 
> > Steps to reproduce:
> > 
> > 1. Start a clean ES setup
> > 2. No index/type mapping should be created
> > 3. Add some content:  
> > curl -XPUT '[http://localhost:9200/items/item/1](http://localhost:9200/items/item/1)' -d  
> > '{"language":"en","description":"some crm description data","title":"some  
> > crm title data"}'
> > 
> > So 1 document in a new index called items with a type called item:
> > 
> > 1. Search for that 1 doc and check the score:  
> > [http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)  
> > 0.13561106
> > 
> > 2. Start adding that same doc multiple times (search every few occurences)  
> > curl -XPUT '[http://localhost:9200/items/item/2](http://localhost:9200/items/item/2)' -d  
> > '{"language":"en","description":"some crm description data","title":"some  
> > crm title data"}'  
> > curl -XPUT '[http://localhost:9200/items/item/3](http://localhost:9200/items/item/3)' -d  
> > '{"language":"en","description":"some crm description data","title":"some  
> > crm title data"}'  
> > curl -XPUT '[http://localhost:9200/items/item/4](http://localhost:9200/items/item/4)' -d  
> > '{"language":"en","description":"some crm description data","title":"some  
> > crm title data"}'  
> > curl -XPUT '[http://localhost:9200/items/item/5](http://localhost:9200/items/item/5)' -d  
> > '{"language":"en","description":"some crm description data","title":"some  
> > crm title data"}'
> > 
> > 3. Search again:  
> > [http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)  
> > Should get the same score as above for all the docs:
> > 
> > 4. Search with title field:  
> > [http://localhost:9200/items/item/\_search?q=title:crm](http://localhost:9200/items/item/_search?q=title:crm)  
> > Same score for all docs (slightly higher but because we check on only 1  
> > field vs all)  
> > 0.15342641
> > 
> > _Gets interesting here!_  
> > \*
> > 
> > - 
> > 1. Add some new docs with slightly different text:  
> > curl -XPUT '[http://localhost:9200/items/item/6](http://localhost:9200/items/item/6)' -d  
> > '{"language":"en","description":"some crm description data","title":"some  
> > crm title data _crm_"}'  
> > curl -XPUT '[http://localhost:9200/items/item/7](http://localhost:9200/items/item/7)' -d  
> > '{"language":"en","description":"_some crm description crm_","title":"_crm  
> > crm_"}'
> > 
> > 1. Now search again:  
> > [http://localhost:9200/items/item/\_search?q=title:crm](http://localhost:9200/items/item/_search?q=title:crm)
> > 
> > Notice that not all the docs get the same score. Obviously i would have  
> > expected different scores for document 6/7 - _but not all of documents  
> > 1-5 (that are all the same) get the same score_:
> > 
> > - {
> > - \_index: "items",
> > - \_type: "item",
> > - \_id: "2",
> > - \_score: 0.2972674,
> > - \_source:  
> > {
> > - language: "en",
> > - description: "some crm description data",
> > - title: "some crm title data"  
> > }  
> > },
> > 
> > - 
> > 
> > {  
> > - \_index: "items",  
> > - \_type: "item",  
> > - \_id: "4",  
> > - \_score: 0.15342641,  
> > - \_source:  
> > {  
> > - language: "en",  
> > - description: "some crm description data",  
> > - title: "some crm title data"  
> > }  
> > }
> > 
> > 1. Same if we don't search title explicitly:  
> > [http://localhost:9200/items/item/\_search?q=crm](http://localhost:9200/items/item/_search?q=crm)
> > 
> > Note the scores are completely different for the same  
> > title/description/etc. Is this issue related to sharding (e.g. documents  
> > mapping to a particular shard?) or something else? The same issue is seen  
> > if we add 6 documents (all the same) to an index with 5 shards - using the  
> > explain plan seems to show that maxDocs for tfidf is calculated over  
> > #shards. Is this expected?
> > 
> > We are using a completely blank es setup of ES 0.90.0, no complex  
> > analyzer/settings/mapping.
> > 
> > [http://localhost:9200/items/\_settings](http://localhost:9200/items/_settings)
> > 
> > {
> > 
> > - items:  
> > {
> > - settings:  
> > {
> > - index.number\_of\_shards: "5",
> > - index.number\_of\_replicas: "1",
> > - index.version.created: "900099"  
> > }  
> > }
> > 
> > }
> > 
> > [http://localhost:9200/\_mapping](http://localhost:9200/_mapping)  
> > {
> > 
> > - items:  
> > {
> > - item:  
> > {
> > - properties:  
> > {
> > - description:  
> > {
> > - type: "string"  
> > },
> > 
> > - language:  
> > {
> > - type: "string"  
> > },
> > 
> > - title:  
> > {
> > - type: "string"  
> > }  
> > }  
> > }  
> > }
> > 
> > }
> > 
> > Help as always greatly appreciated
> > 
> > Derry
> > 
> > --  
> > You received this message because you are subscribed to the Google Groups  
> > "elasticsearch" group.  
> > To unsubscribe from this group and stop receiving emails from it, send an  
> > email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to a topic in the  
> Google Groups "elasticsearch" group.  
> To unsubscribe from this topic, visit  
> [https://groups.google.com/d/topic/elasticsearch/lFq\_V3PiRwA/unsubscribe?hl=en-US](https://groups.google.com/d/topic/elasticsearch/lFq_V3PiRwA/unsubscribe?hl=en-US)  
> .  
> To unsubscribe from this group and all its topics, send an email to  
> [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Clinton\_Gormley](https://avatars.discourse-cdn.com/v4/letter/c/50afbb/32.png) [@Clinton\_Gormley](https://discuss.elastic.co/u/Clinton_Gormley)\
**Post date:** [May 23, 2013, 10:06am UTC](https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057/4 "2013-05-23T10:06:49Z")

</div>

The results that you are seeing are an artefact of having too few docs in a  
distributed environment. With a real application, you have many more docs,  
so the differences even out.

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Derry\_O\_Sullivan](https://avatars.discourse-cdn.com/v4/letter/d/7bcc69/32.png) [@Derry\_O\_Sullivan](https://discuss.elastic.co/u/Derry_O_Sullivan)\
**Post date:** [May 23, 2013, 10:09am UTC](https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057/5 "2013-05-23T10:09:07Z")

</div>

Hey Clinton,

Thanks for that. I understand the concept that over time/with lots of  
documents, the scoring stabilizes. I guess the real q is for a beginner  
database (e.g. from the tutorial/etc) where you insert a low number of  
documents, this is probably going to be quite confusing as the default  
shard size is 5. Then again, i guess people are not going to be adding the  
same content multiple times 😉

Derry

On 23 May 2013 11:06, Clinton Gormley [clint@traveljury.com](mailto:clint@traveljury.com) wrote:

> The results that you are seeing are an artefact of having too few docs in  
> a distributed environment. With a real application, you have many more  
> docs, so the differences even out.
> 
> --  
> You received this message because you are subscribed to a topic in the  
> Google Groups "elasticsearch" group.  
> To unsubscribe from this topic, visit  
> [https://groups.google.com/d/topic/elasticsearch/lFq\_V3PiRwA/unsubscribe?hl=en-US](https://groups.google.com/d/topic/elasticsearch/lFq_V3PiRwA/unsubscribe?hl=en-US)  
> .  
> To unsubscribe from this group and all its topics, send an email to  
> [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Clinton\_Gormley](https://avatars.discourse-cdn.com/v4/letter/c/50afbb/32.png) [@Clinton\_Gormley](https://discuss.elastic.co/u/Clinton_Gormley)\
**Post date:** [May 23, 2013, 10:53am UTC](https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057/6 "2013-05-23T10:53:10Z")

</div>

It is a common source of confusion. But being able to scale out  
automatically by default has greater benefit, hence the multiple shards

clint

On 23 May 2013 12:09, Derry O' Sullivan [derryos@gmail.com](mailto:derryos@gmail.com) wrote:

> Hey Clinton,
> 
> Thanks for that. I understand the concept that over time/with lots of  
> documents, the scoring stabilizes. I guess the real q is for a beginner  
> database (e.g. from the tutorial/etc) where you insert a low number of  
> documents, this is probably going to be quite confusing as the default  
> shard size is 5. Then again, i guess people are not going to be adding the  
> same content multiple times 😉
> 
> Derry
> 
> On 23 May 2013 11:06, Clinton Gormley [clint@traveljury.com](mailto:clint@traveljury.com) wrote:
> 
> > The results that you are seeing are an artefact of having too few docs in  
> > a distributed environment. With a real application, you have many more  
> > docs, so the differences even out.
> > 
> > --  
> > You received this message because you are subscribed to a topic in the  
> > Google Groups "elasticsearch" group.  
> > To unsubscribe from this topic, visit  
> > [https://groups.google.com/d/topic/elasticsearch/lFq\_V3PiRwA/unsubscribe?hl=en-US](https://groups.google.com/d/topic/elasticsearch/lFq_V3PiRwA/unsubscribe?hl=en-US)  
> > .  
> > To unsubscribe from this group and all its topics, send an email to  
> > [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to the Google Groups  
> "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an  
> email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![system](https://us1.discourse-cdn.com/elastic/original/3X/1/a/1ac57faf039f6b580b3f104ef42a2a89e41014de.png) [@system](https://discuss.elastic.co/u/system)\
**Post date:** [July 6, 2017, 2:35am UTC](https://discuss.elastic.co/t/strange-issue-with-similarity-scores-on-es-0-90-0-possibly-shard-related/12057/7 "2017-07-06T02:35:09Z")

</div>


